% This script enables the user to load multiple .mat files, and
% concatenate the variable "exportmat" of all files vertically. The user
% is then prompted to save the resulting array to a .mat file.
% Bastian Hablitzel, April 2013

[files, pathname, filterindex] = uigetfile( ...
{  '*.mat','MAT-files (*.mat)'; ...
   '*.*',  'All Files (*.*)'}, ...
   'Open multiple exportmat files to pool your data of the whole brain', ...
   'MultiSelect', 'on');                     % select the files to be merged
if( isempty( files ) )
    var = [];
    return;
end

varname='exportmat';

var = load(fullfile(pathname, files{1}), varname ); % load data
var = var.(varname);

for f = 2:numel(files),                             %  merge the data

    newvar = load(fullfile(pathname, files{f}), varname ); 
        if( isfield( newvar, varname ) )
            var = cat(1, var, newvar.(varname) );
        else
            warning('FileCat:VarMissing', ['Warning: File ' files{f} ' does not contain variable ' varname ] );
        end
end
exportmat=var;

[SaveFileName,SavePathName] = uiputfile('Rec_pooled_data_of_the brain_.mat','name the new file');  %  save the data
save([SavePathName,SaveFileName],'exportmat');




